
[![hammadpy 2.1.0](https://img.shields.io/badge/dependency-hammadpy-blue?logo=pypi&logoColor=white)](https://pypi.org/project/hammadpy)

[python.hammad.fun](https://python.hammad.fun)

# HammadPy

```bash
pip install hammadpy
```

The **HammadPy** library, is an 'accidentally' developed toolkit for simplifying a variety of tasks. <br/>
<br/>


---


**Core Features**
> - Styled Text Outputs <br/>
> - Styled Text Strings <br/>
> - Loading Placeholders <br/>
> - Data Handling <br/>
> - Variable Verification <br/>


---


**Generative AI**
> - Simple & Templated LLM API Queries to OpenAI or Huggingface
> - Modular *'instructor'* implementation (use premade models, or define own).
> - DALLE Image Generation (URL & PNG)
> - Huggingface Inference API's


---


**Pydantic Modeling**
> - Variety of premade Pydantic Models; or build your own.


---


**Web Tools**
> - Easy UI Building with Dash
> - Modular & Simple FastAPI Implementation
> - Plug and play requests (Easy HTTP requests, using the 'requests library)


---


**Machine Learning Kit**
> - SentenceBERT implementation for NLP tasks.
> - Simple scikit-learn alogrithm implementations (Clustering, Regression, Classification)
> - *'Essential'* natural-language tools, using spaCy and nltk.


---


**Experimental (Very Faulty!)**
> - Modular GUI implementation, with tkinter.


---


### The HammadPy library is available globally on [Pypi](https://pypi.org/project/hammadpy/), you can install it using:

```python
pip install hammadpy
```
